@@ -1,17 +1,16 @@
 package Bot::IRC::History;
 # ABSTRACT: Bot::IRC selected channel history dumped to email
 
-use 5.012;
-use strict;
-use warnings;
+use 5.014;
+use exact;
 
+use Date::Format 'time2str';
+use Date::Parse 'str2time';
+use Email::Mailer;
 use Email::Valid;
 use File::Grep 'fgrep';
-use Date::Parse 'str2time';
-use Date::Format 'time2str';
-use Email::Mailer;
 
-our $VERSION = '1.27'; # VERSION
+our $VERSION = '1.28'; # VERSION
 
 sub init {
     my ($bot)       = @_;
@@ -152,7 +151,7 @@ Bot::IRC::History - Bot::IRC selected channel history dumped to email
 
 =head1 VERSION
 
-version 1.27
+version 1.28
 
 =head1 SYNOPSIS
 
@@ -207,9 +206,10 @@ Gryphon Shafer <gryphon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Gryphon Shafer.
+This software is Copyright (c) 2016-2021 by Gryphon Shafer.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
