@@ -1,14 +1,13 @@
 package Bot::IRC::Seen;
 # ABSTRACT: Bot::IRC track when and where users were last seen
 
-use 5.012;
-use strict;
-use warnings;
+use 5.014;
+use exact;
 
 use DateTime;
 use DateTime::Format::Human::Duration;
 
-our $VERSION = '1.27'; # VERSION
+our $VERSION = '1.28'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -68,7 +67,7 @@ Bot::IRC::Seen - Bot::IRC track when and where users were last seen
 
 =head1 VERSION
 
-version 1.27
+version 1.28
 
 =head1 SYNOPSIS
 
@@ -100,9 +99,10 @@ Gryphon Shafer <gryphon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Gryphon Shafer.
+This software is Copyright (c) 2016-2021 by Gryphon Shafer.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
